package busicode;

import java.util.HashMap;
import java.util.Map;

import org.springframework.lang.Nullable;

/**
 * 处理【第三方与系统的入口 (主要提供给第三方使用)】业务逻辑
 */
public class BusiEnter {

	// 【OctCommonCodeSystemWeb 各项目通用代码项目】 API请求地址, 注意这个根据实现配置的情况而定
	public static String OctCommonCodeSystemWeb_ApiDomain = "http://192.168.3.10:8000";

	// 获取RSA加密后的RndKey, 即签名后的Key 请求路径
	public static String ApiUrl_GetRndKeyRSA = OctCommonCodeSystemWeb_ApiDomain + "/Key/GetRndKeyRSA";

	// API接口请求配置的【API用户ID (UserKeyID)】 可在平台管理系统中设置 进入平台管理系统：
	// 【系统管理】->【API接口管理】->【API用户管理】
	public static String mUserKeyID = "8823466";
	// API接口请求配置的【UserKey值(UserKey)】 可在平台管理系统中设置 进入平台管理系统：
	// 【系统管理】->【API接口管理】->【API用户管理】
	public static String mUserKey = "9af7f46a-2563-4aa3-b8c3-9fd484c2af88";

	// private static String mApiKey = "95a0abe5-17a1-4bad-982a-8586f886a638";

	/**
	 * 构造函数
	 */
	public BusiEnter() {

	}

	/// <summary>
	/// 测试 -- 》》调用【买家用户的 账号，买家信息，余额积分信息 API接口】   ##########################################
	/// </summary>
	/// <returns></returns>
	public static String testApiDemo() {

		// 构造POST参数,这里是接口需要的参数
		Map<String, Object> _postParam = new HashMap<String, Object>();
		_postParam.put("Type", "5");
		_postParam.put("BuyerUserID", "30103");

		// 调用发送Http的方法，封装了RndKeyRSA签名 其中 http://192.168.3.10:8001/User/UserAccount
		// 是API接口URL地址
		String _jsonBack = httpRndKeyRsa("http://192.168.3.10:8001/User/UserAccount", "UGS_UserAccount", _postParam);
		return _jsonBack;
	}

	/// <summary>
	/// 带RndKeyRSA的Http请求方法
	/// </summary>
	/// <param name="pHttpUrl">API请求的URL
	/// [http://192.168.1.220:1200/Test/VerifyApiNoLogin]</param>
	/// <param name="pVerifyType">Http验证类型,接口说明里面有</param>
	/// <param name="pPostParamDic">额外传递的POST参数</param>
	/// <param name="pHeaderParameters">添加Header键值
	/// var parameters1 = new Dictionary<string, string>();
	/// parameters1.Add("Name", "小黄人");
	/// parameters1.Add("Age", "31");
	/// parameters1.Add("Work", "IT工程师");
	/// 获取Header值如下：
	/// string HeaderName =
	/// HttpUtility.UrlDecode(Request.Headers["HeaderName"].ToString().Trim());
	/// </param>
	/// <param name="isUseCert">是否使用了证书</param>
	/// <param name="timeout">超时时间</param>
	/// <returns></returns>
	public static String httpRndKeyRsa(String pHttpUrl, String pVerifyType, Map<String, Object> pPostParamMap) {
		// 得到RSA加密后的RndKey
		String _rndKeyRSA = getRndKeyRSA();

		// 构造POST参数
		Map<String, Object> _postParam = new HashMap<String, Object>();
		_postParam.put("RndKeyRSA", _rndKeyRSA);
		_postParam.put("LangType", "Java");
		_postParam.put("VerifyType", pVerifyType);
		// 合并两个Map
		_postParam.forEach((key, value) -> pPostParamMap.merge(key, value, (v1, v2) -> ""));

		// 发送Http请求
		String _jsonBack = HttpUtil.doPostString(pHttpUrl, pPostParamMap);
		return _jsonBack;
	}

	/// <summary>
	/// 得到RSA加密后RndKey 即签名RndKey, 请特别注意：这里获取的RndKeyRSA一般是两个小时有效，请保存在文件中，
	/// 没有超过两个小时，直接读取文件中的即可，超过了更新文件中的RndKeyRSA再读取，这样就可以提高系统的性能。
	/// </summary>
	/// <returns></returns>
	public static String getRndKeyRSA() {
		// 通过Http请求获取RSA加密后的RndKey
		String _rndKeyRSA = httpGetRndKeyRSA(ApiUrl_GetRndKeyRSA, mUserKeyID, mUserKey, "false");
		return _rndKeyRSA;
	}

	/// <summary>
	/// 通过Http请求获取RSA加密后的RndKey, 一种是两小时有效，别一种只能使用一次
	/// </summary>
	/// <param name="pHttpURL">Http请求URL地址</param>
	/// <param name="pUserKeyID">API用户ID(Key关联的用户ID) 与UserKey对应的UserKeyID</param>
	/// <param name="pUserKey">系统分配给Api请求用户的Key值
	/// [9af7f46a-ea52-4aa3-b8c3-9fd484c2af12]</param>
	/// <param name="pOneTime">RndKey是否为只使用一次 [true/false]</param>
	/// <returns></returns>
	public static String httpGetRndKeyRSA(String pHttpURL, String pUserKeyID, String pUserKey, String pOneTime) {
		String _rndKey = pUserKeyID + "^" + pUserKey + "^" + pOneTime + "^" + PublicUtil.getTotalMilliSeconds();
		// 加密获取RndKey所需要的信息
		String _keyIDUserKeyArr = RSAMD5Utils.RSAEncryptSection(_rndKey, '~');

		// 必须将加密后文本中的“+”转换成“%2B” 再通过GET方式参数传递 否则会出现“base64长度和加密字符串不正确的错误”
		_keyIDUserKeyArr = _keyIDUserKeyArr.replaceAll("\\+", "%2B");

		// 构造POST参数
		Map<String, Object> _postParam = new HashMap<String, Object>();
		_postParam.put("UserKeyIDAndUserKeyArrRSA", _keyIDUserKeyArr);
		_postParam.put("LangType", "Java");
		// 发送Http请求
		String _rndKeyRSA = HttpUtil.doPostString(pHttpURL, _postParam);
		return _rndKeyRSA;
	}



}
