package busicode;

import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.net.ConnectException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.Map;
import java.util.Map.Entry;

import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import javax.servlet.http.HttpServletRequest;

import com.alibaba.fastjson.JSONObject;

//import com.alibaba.fastjson.JSONObject;

/**
 * 
 * @项目名称: --
 * @版权所有: --
 * @技术支持: --
 * @单元名称: http协议GET/POST请求工具类
 * @开始时间: 2018-12-14
 * @开发人员: -- 黄友许
 */
public class HttpUtil {

//	public static void main(String[] args) {
//		String url = "http://localhost:8080/";
//		JSONObject params = new JSONObject();
//		params.put("type", 1);
//		params.put("value", true);
//		System.out.println(doGet(url, params));
//	}

	/**
	 * Http的POST请求 返回String数据
	 * 
	 * @param pHttpURL   Http请求的URL
	 * @param pMapParams Map键值对
	 * @return
	 */
	public static String doPostString(String pHttpURL, Map<String, Object> pMapParams) {

		String result = "";

		OutputStream out = null;
		DataOutputStream dataOutputStream = null;
		InputStream in = null;
		ByteArrayOutputStream baos = null;
		try {
			URLConnection urlConnection = new URL(pHttpURL).openConnection();
			HttpURLConnection httpUrlConnection = (HttpURLConnection) urlConnection;
			// 设置是否向httpUrlConnection输出，post请求，参数要放在http正文内，因此需要设为true,
			// 默认情况下是false;
			httpUrlConnection.setDoOutput(true);
			// 设置是否从httpUrlConnection读入，默认情况下是true;
			httpUrlConnection.setDoInput(true);
			// 忽略缓存
			httpUrlConnection.setUseCaches(false);
			// 设定请求的方法为"POST"，默认是GET
			httpUrlConnection.setRequestMethod("POST");
			httpUrlConnection.connect();

			// 建立输入流，向指向的URL传入参数

			String queryString = "";

			if (pMapParams != null) {
//				for (Entry<String, Object> entry : params.entrySet()) {
//					queryString += entry.getKey() + "=" + URLEncoder.encode(entry.getValue().toString(), "UTF-8") + "&";
//				}

				// 遍历Map键值对对象的集合，得到每一个键值对对象
				for (Entry<String, Object> entry : pMapParams.entrySet()) {

					queryString += entry.getKey() + "=" + URLEncoder.encode(entry.getValue().toString(), "UTF-8") + "&";
				}
			}

			if (queryString.length() > 0) {
				queryString = queryString.substring(0, queryString.length() - 1);
				out = httpUrlConnection.getOutputStream();
				dataOutputStream = new DataOutputStream(out);
				dataOutputStream.writeBytes(queryString);

				dataOutputStream.flush();
				out.flush();
			}

			// 获得响应状态
			int responseCode = httpUrlConnection.getResponseCode();

			if (HttpURLConnection.HTTP_OK == responseCode) {
				baos = new ByteArrayOutputStream();
				byte[] buffer = new byte[1024];
				int len = 0;
				in = httpUrlConnection.getInputStream();
				while ((len = in.read(buffer)) != -1) {
					baos.write(buffer, 0, len);
					baos.flush();
				}

				// 返回请求数据
				result = baos.toString("UTF-8");

			} else {
				result = "code=" + responseCode + "，msg=请求异常";
			}

			// 关闭连接
			httpUrlConnection.disconnect();

		} catch (Exception e) {
			result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
		} finally {

			if (baos != null) {
				try {
					baos.close();
				} catch (IOException e) {
					result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
				}
			}
			if (in != null) {
				try {
					in.close();
				} catch (IOException e) {
					result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
				}
			}
			if (dataOutputStream != null) {
				try {
					dataOutputStream.close();
				} catch (IOException e) {
					result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
				}
			}
			if (out != null) {
				try {
					out.close();
				} catch (IOException e) {
					result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
				}
			}
		}

		return result;
	}

	/**
	 * HTTP的GET请求 返回String数据
	 * 
	 * @param pHttpURL   Http请求的URL
	 * @param pMapParams Map对象参数
	 * @return
	 */
	public static String doGetString(String pHttpURL, Map<String, Object> pMapParams) {

		String result = "";

		InputStream in = null;
		ByteArrayOutputStream baos = null;

		try {
			// URL传入参数
			String queryString = "";

			if (pMapParams != null) {
				for (Entry<String, Object> entry : pMapParams.entrySet()) {
					queryString += entry.getKey() + "=" + URLEncoder.encode(entry.getValue().toString(), "UTF-8") + "&";

				}
			}

			if (queryString.length() > 0) {
				queryString = queryString.substring(0, queryString.length() - 1);

				pHttpURL = pHttpURL + "?" + queryString;
			}

			URLConnection urlConnection = new URL(pHttpURL).openConnection();
			HttpURLConnection httpUrlConnection = (HttpURLConnection) urlConnection;
			// 设置是否向httpUrlConnection输出，post请求，参数要放在http正文内，因此需要设为true,
			// 默认情况下是false;
			httpUrlConnection.setDoOutput(false);
			// 设置是否从httpUrlConnection读入，默认情况下是true;
			httpUrlConnection.setDoInput(true);
			// 忽略缓存
			httpUrlConnection.setUseCaches(false);
			// 设定请求的方法为"POST"，默认是GET
			httpUrlConnection.setRequestMethod("GET");
			httpUrlConnection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
			httpUrlConnection.setRequestProperty("Charset", "utf-8");

			httpUrlConnection.connect();

			// 获得响应状态
			int responseCode = httpUrlConnection.getResponseCode();

			if (HttpURLConnection.HTTP_OK == responseCode) {

				baos = new ByteArrayOutputStream();

				byte[] buffer = new byte[1024];
				int len = 0;
				in = httpUrlConnection.getInputStream();
				while ((len = in.read(buffer)) != -1) {
					baos.write(buffer, 0, len);
					baos.flush();
				}

				// 返回请求成功的数据
				result = baos.toString("UTF-8");

			} else {
				result = "code=" + responseCode + "，msg=请求异常";
			}

			// 关闭链接
			httpUrlConnection.disconnect();

		} catch (Exception e) {
			result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
		} finally {
			if (baos != null) {
				try {
					baos.close();
				} catch (IOException e) {
					result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
				}
			}
			if (in != null) {
				try {
					in.close();
				} catch (IOException e) {
					result = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
				}
			}
		}

		return result;
	}

	/**
	 * 以POST 方式发送 Json数据 可传Header数据
	 * 
	 * @param pHttpURL      请求的URL
	 * @param pJsonString   JSON字符串
	 * @param pHeaderParams Header数据Map集合
	 * @return
	 */
	public static String doPostJson(String pHttpURL, String pJsonString, Map<String, Object> pHeaderParams) {
		String jsonString = "";
		try {
			// 创建连接
			URL url = new URL(pHttpURL);
			HttpURLConnection connection = (HttpURLConnection) url.openConnection();
			connection.setDoOutput(true);
			connection.setDoInput(true);
			connection.setRequestMethod("POST"); // 设置请求方法
			connection.setRequestProperty("Charsert", "UTF-8"); // 设置请求编码
			connection.setUseCaches(false);
			connection.setInstanceFollowRedirects(true);
			// 一定要设置 Content-Type 要不然服务端接收不到参数
			connection.setRequestProperty("Content-Type", "application/Json; charset=UTF-8");

			if (pHeaderParams != null) {
				for (Entry<String, Object> entry : pHeaderParams.entrySet()) {
					// queryString += entry.getKey() + "=" +
					// URLEncoder.encode(entry.getValue().toString(), "UTF-8") + "&";
					// 设置头部数据值
					connection.setRequestProperty("" + entry.getKey() + "",
							URLEncoder.encode(entry.getValue().toString(), "UTF-8"));
				}
			}

			connection.connect();

			// POST请求
//			DataOutputStream out = new DataOutputStream(connection.getOutputStream()); // 关键的一步
//			out.writeBytes(obj);

			PrintWriter out = new PrintWriter(new OutputStreamWriter(connection.getOutputStream(), "utf-8"));
			out.println(pJsonString);

			out.flush();
			out.close();

			// 读取响应
			if (connection.getResponseCode() == 200) {
				BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
				String lines;
				StringBuffer sb = new StringBuffer("");
				while ((lines = reader.readLine()) != null) {
					lines = new String(lines.getBytes(), "utf-8");
					sb.append(lines);
				}
				jsonString = sb.toString();
				reader.close();
			} // 返回值为200输出正确的响应信息

			if (connection.getResponseCode() == 400) {
				BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getErrorStream()));
				String lines;
				StringBuffer sb = new StringBuffer("");
				while ((lines = reader.readLine()) != null) {
					lines = new String(lines.getBytes(), "utf-8");
					sb.append(lines);
				}
				jsonString = sb.toString();
				reader.close();
			} // 返回值错误，输出错误的返回信息
				// 断开连接
			connection.disconnect();
		} catch (MalformedURLException e) {
			// TODO Auto-generated catch block
			jsonString = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
			e.printStackTrace();
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			jsonString = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			jsonString = "code=500，msg=请求异常，异常信息：\"" + e.getClass() + "\"->\"" + e.getMessage();
		}
		return jsonString;
	}

	/**
	 * 得到Http以POST方式发送过来的Json数据
	 * 
	 * @param pReq Request对象
	 * @return
	 */
	public static String getPostJsonData(HttpServletRequest pReq) {
		String _reqContent = "";

		try {
			BufferedReader streamReader = new BufferedReader(new InputStreamReader(pReq.getInputStream(), "UTF-8"));
			StringBuilder responseStrBuilder = new StringBuilder();

			String inputStr = "";
			while ((inputStr = streamReader.readLine()) != null) {
				responseStrBuilder.append(inputStr);
			}
			System.out.println(responseStrBuilder);

			_reqContent = responseStrBuilder.toString();

		} catch (Exception e) {
			// e.printStackTrace();
			System.out.println("获取Json数据流出错！");
		}

		return _reqContent.trim();
	}

	/**
	 * 得到 Request的Header传递的参数值
	 * 
	 * @param pReq
	 * @param pHeaderName
	 * @return
	 */
	public static String getHeaderDataVal(HttpServletRequest pReq, String pHeaderName) {

		String _headerName = "";
		try {
			_headerName = URLDecoder.decode(pReq.getHeader("" + pHeaderName + ""), "UTF-8");
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			// e.printStackTrace();
			System.out.println("Header数据【" + pHeaderName + "】为Null");
		}
		return _headerName.trim();
	}

	/**
	 * 获取 Http请求传递过来的参数值
	 * 
	 * @param pReq       HttpServletRequest 对象
	 * @param pParamName 参数名称值
	 * @return
	 */
	public static String getHttpParamVal(HttpServletRequest pReq, String pParamName) {

		String _httpParamVal = "";

		try {
			_httpParamVal = pReq.getParameter("" + pParamName + "");
		} catch (Exception e) {
			System.out.println("获取Http参数【" + pParamName + "】值出错！");
		}
		
		if (_httpParamVal == null)
		{
			_httpParamVal = "";
		}

		return _httpParamVal.trim();
	}

	/**
	 * 过滤特殊字符，防止SQL注入攻击
	 * 
	 * @param pStrInput 输入字符串
	 * @return
	 */
	public static String StrConvert(String pStrInput) {
		if ((pStrInput != null) && (pStrInput != "")) {
			// 定义需要过滤的字符。
			String[][] immit = { { "'", "’" }, { "%20", " " }, { "%24", " " }, { "%27", " " }, { "%3a", " " },
					{ "%3b", " " }, { "%3c", " " }, { ";", "；" }, { "+", "＋" }, { "&", "＆" }, { "(", "（" },
					{ ")", "）" }, { "%", "％" }, { "--", "－－" }, { "*", "※" }, { "\\", "、" }, { "|", "｜" }, { "@", "＠" },
					{ "[", "【" }, { "]", "】" }, { "#", "＃" } };
			// 遍历字符串，过滤掉需要过滤的字符
			for (int i = 0; i < (immit.length); i++) {
				// pStrInput = pStrInput.replace(immit[i, 0], immit[i, 1]);
				pStrInput = pStrInput.replace(immit[i][0], immit[i][1]);

				// System.out.println(immit[i][0] + "=" + immit[i][1]);
			}
		}
		return pStrInput;// 返回替换后的字符串
	}

	/**
	 * 过滤掉前台文本框中Xhtml代码，以及特殊攻击字符,并将文本框的值的空格去掉
	 * 
	 * @param pReq        HttpServletRequest 对象
	 * @param RequestName 传递的参数名称
	 * @return
	 */
	public static String FilterRequestTrim(HttpServletRequest pReq, String pRequestName) {
		// 得到传递的参数 ，如果为Null 则返回 “” 空值
		String _textValue = getHttpParamVal(pReq, pRequestName);

		if (isNullOrWhiteSpace(_textValue) == false) {
			// 对Xhtml的<>符进行处理
			_textValue = _textValue.replace(">", "&gt;").toString();
			_textValue = _textValue.replace("<", "&lt;").toString();

			// 去掉可能有攻击的字符串
			_textValue = StrConvert(_textValue);
		}

		return _textValue;
	}

	/**
	 * 过滤掉前台文本框中Xhtml代码，并将文本框的值的空格去掉 不除去有攻击的字符
	 * 
	 * @param pReq        HttpServletRequest 对象
	 * @param RequestName 传递的参数名称
	 * @return
	 */
	public static String FilterRequestTrimNoConvert(HttpServletRequest pReq, String pRequestName) {
		// 得到传递的参数 ，如果为Null 则返回 “” 空值
		String _textValue = getHttpParamVal(pReq, pRequestName);

		if (isNullOrWhiteSpace(_textValue) == false) {
			// 对Xhtml的<>符进行处理
			_textValue = _textValue.replace(">", "&gt;").toString();
			_textValue = _textValue.replace("<", "&lt;").toString();

			// 去掉可能有攻击的字符串
			// _textValue = StrConvert(_textValue);
		}

		return _textValue;
	}

	/**
	 * 获取Http中的Header传递的参数值 并 过滤掉前台文本框中Xhtml代码，以及特殊攻击字符,并将文本框的值的空格去掉
	 * 
	 * @param pReq         HttpServletRequest 对象
	 * @param pRequestName 传递的参数名称
	 * @return
	 */
	public static String FilterRequestHeaderTrim(HttpServletRequest pReq, String pRequestName) {
		// 获取前台传递过来的值
		String _textValue = getHeaderDataVal(pReq, pRequestName);

		if (isNullOrWhiteSpace(_textValue) == false) {
			// 对Xhtml的<>符进行处理
			_textValue = _textValue.replace(">", "&gt;").toString();
			_textValue = _textValue.replace("<", "&lt;").toString();

			// 去掉可能有攻击的字符串
			_textValue = StrConvert(_textValue);
		}

		return _textValue;
	}

	/**
	 * 获取Http中的Header传递的参数值 并 过滤掉前台文本框中Xhtml代码，并将文本框的值的空格去掉 不除去有攻击的字符
	 * 
	 * @param pReq         HttpServletRequest 对象
	 * @param pRequestName 传递的参数名称
	 * @return
	 */
	public static String FilterRequestHeaderTrimNoConvert(HttpServletRequest pReq, String pRequestName) {
		// 获取前台传递过来的值
		String _textValue = getHeaderDataVal(pReq, pRequestName);

		if (isNullOrWhiteSpace(_textValue) == false) {
			// 对Xhtml的<>符进行处理
			_textValue = _textValue.replace(">", "&gt;").toString();
			_textValue = _textValue.replace("<", "&lt;").toString();

			// 去掉可能有攻击的字符串
			//_textValue = StrConvert(_textValue);
		}

		return _textValue;
	}

	/**
	 * 判断字符串是否为空
	 * 
	 * @param pString 要判断的字符串
	 * @return
	 */
	public static Boolean isNullOrWhiteSpace(String pString) {

		if (pString != null) {
			if (pString.trim().equals("") == false) {
				return false; // 不为空
			}
		}

		return true; // 为空
	}

	
	
	/**
	 * 发送https请求 - 支持带证书
	 * @param requestUrl    请求地址
	 * @param requestMethod 请求方式（GET、POST）
	 * @param outputStr     提交的数据
	 * @return JSONObject(通过JSONObject.get(key)的方式获取json对象的属性值)
	 */
	public static JSONObject httpsRequest(String requestUrl, String requestMethod, String outputStr) {
		JSONObject jsonObject = null;
		try {
			// 创建SSLContext对象，并使用我们指定的信任管理器初始化
			TrustManager[] tm = { new MyX509TrustManager() };
			SSLContext sslContext = SSLContext.getInstance("SSL", "SunJSSE");
			sslContext.init(null, tm, new java.security.SecureRandom());
			// 从上述SSLContext对象中得到SSLSocketFactory对象
			SSLSocketFactory ssf = sslContext.getSocketFactory();

			URL url = new URL(requestUrl);
			HttpsURLConnection conn = (HttpsURLConnection) url.openConnection();
			conn.setSSLSocketFactory(ssf);

			conn.setDoOutput(true);
			conn.setDoInput(true);
			conn.setUseCaches(false);
			// 设置请求方式（GET/POST）
			conn.setRequestMethod(requestMethod);

			// 当outputStr不为null时向输出流写数据
			if (null != outputStr) {
				OutputStream outputStream = conn.getOutputStream();
				// 注意编码格式
				outputStream.write(outputStr.getBytes("UTF-8"));
				outputStream.close();
			}

			// 从输入流读取返回内容
			InputStream inputStream = conn.getInputStream();
			InputStreamReader inputStreamReader = new InputStreamReader(inputStream, "utf-8");
			BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
			String str = null;
			StringBuffer buffer = new StringBuffer();
			while ((str = bufferedReader.readLine()) != null) {
				buffer.append(str);
			}

			// 释放资源
			bufferedReader.close();
			inputStreamReader.close();
			inputStream.close();
			inputStream = null;
			conn.disconnect();
			jsonObject = JSONObject.parseObject(buffer.toString());
		} catch (ConnectException ce) {
			System.out.printf("连接超时：{" + ce + "}");
		} catch (Exception e) {
			System.out.printf("https请求异常：{}", e);
		}
		return jsonObject;
	}

	/**
	 * 证书信任管理器（用于https请求） 这个证书管理器的作用就是让它信任我们指定的证书，下面的代码意味着信任所有证书，不管是否权威机构颁发。
	 * 
	 * @author：WangYuanJun
	 * @date：2018年1月23日 下午3:22:19
	 */
	public static class MyX509TrustManager implements X509TrustManager {

		// 检查客户端证书
		public void checkClientTrusted1(X509Certificate[] chain, String authType) throws CertificateException {
		}

		// 检查服务器端证书
		public void checkServerTrusted1(X509Certificate[] chain, String authType) throws CertificateException {
		}

		// 返回受信任的X509证书数组
		public X509Certificate[] getAcceptedIssuers1() {
			return null;
		}

		@Override
		public void checkClientTrusted(X509Certificate[] chain, String authType) throws CertificateException {
			// TODO Auto-generated method stub

		}

		@Override
		public void checkServerTrusted(X509Certificate[] chain, String authType) throws CertificateException {
			// TODO Auto-generated method stub

		}

		@Override
		public X509Certificate[] getAcceptedIssuers() {
			// TODO Auto-generated method stub
			return null;
		}
	}
	
	
//	/**
//	 * Http的POST请求 传输与返回JSON对象数据
//	 * 
//	 * @param url    請求的URL
//	 * @param params Json对象参数
//	 * @return
//	 */
//	public static JSONObject doPostJson(String url, JSONObject params) {
//
//		JSONObject result = new JSONObject();
//		result.put("success", true);
//		result.put("data", null);
//		result.put("code", 200);
//		result.put("msg", null);
//
//		OutputStream out = null;
//		DataOutputStream dataOutputStream = null;
//		InputStream in = null;
//		ByteArrayOutputStream baos = null;
//		try {
//			URLConnection urlConnection = new URL(url).openConnection();
//			HttpURLConnection httpUrlConnection = (HttpURLConnection) urlConnection;
//			// 设置是否向httpUrlConnection输出，post请求，参数要放在http正文内，因此需要设为true,
//			// 默认情况下是false;
//			httpUrlConnection.setDoOutput(true);
//			// 设置是否从httpUrlConnection读入，默认情况下是true;
//			httpUrlConnection.setDoInput(true);
//			// 忽略缓存
//			httpUrlConnection.setUseCaches(false);
//			// 设定请求的方法为"POST"，默认是GET
//			httpUrlConnection.setRequestMethod("POST");
//			httpUrlConnection.connect();
//
//			// 建立输入流，向指向的URL传入参数
//
//			String queryString = "";
//
//			if (params != null) {
//				for (Entry<String, Object> entry : params.entrySet()) {
//					queryString += entry.getKey() + "=" + URLEncoder.encode(entry.getValue().toString(), "UTF-8") + "&";
//				}
//			}
//
//			if (queryString.length() > 0) {
//				queryString = queryString.substring(0, queryString.length() - 1);
//				out = httpUrlConnection.getOutputStream();
//				dataOutputStream = new DataOutputStream(out);
//				dataOutputStream.writeBytes(queryString);
//
//				dataOutputStream.flush();
//				out.flush();
//			}
//
//			// 获得响应状态
//			int responseCode = httpUrlConnection.getResponseCode();
//
//			if (HttpURLConnection.HTTP_OK == responseCode) {
//				baos = new ByteArrayOutputStream();
//				byte[] buffer = new byte[1024];
//				int len = 0;
//				in = httpUrlConnection.getInputStream();
//				while ((len = in.read(buffer)) != -1) {
//					baos.write(buffer, 0, len);
//					baos.flush();
//				}
//
//				result.put("success", true);
//				result.put("data", baos.toString("UTF-8"));
//				result.put("code", 200);
//				result.put("msg", "请求成功");
//			} else {
//				result.put("success", false);
//				result.put("code", responseCode);
//				result.put("msg", "请求异常");
//			}
//		} catch (Exception e) {
//			result.put("success", false);
//			result.put("code", 500);
//			result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//		} finally {
//			if (baos != null) {
//				try {
//					baos.close();
//				} catch (IOException e) {
//					result.put("success", false);
//					result.put("code", 500);
//					result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//				}
//			}
//			if (in != null) {
//				try {
//					in.close();
//				} catch (IOException e) {
//					result.put("success", false);
//					result.put("code", 500);
//					result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//				}
//			}
//			if (dataOutputStream != null) {
//				try {
//					dataOutputStream.close();
//				} catch (IOException e) {
//					result.put("success", false);
//					result.put("code", 500);
//					result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//				}
//			}
//			if (out != null) {
//				try {
//					out.close();
//				} catch (IOException e) {
//					result.put("success", false);
//					result.put("code", 500);
//					result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//				}
//			}
//		}
//
//		return result;
//	}
//
//	/**
//	 * HTTP的GET请求 传输与返回JSON对象数据
//	 * 
//	 * @param url    請求的URL
//	 * @param params Json对象参数
//	 * @return
//	 */
//	public static JSONObject doGetJson(String url, JSONObject params) {
//
//		JSONObject result = new JSONObject();
//		result.put("success", true);
//		result.put("data", null);
//		result.put("code", 200);
//		result.put("msg", null);
//
//		InputStream in = null;
//		ByteArrayOutputStream baos = null;
//
//		try {
//			// URL传入参数
//			String queryString = "";
//
//			if (params != null) {
//				for (Entry<String, Object> entry : params.entrySet()) {
//					queryString += entry.getKey() + "=" + URLEncoder.encode(entry.getValue().toString(), "UTF-8") + "&";
//
//				}
//			}
//
//			if (queryString.length() > 0) {
//				queryString = queryString.substring(0, queryString.length() - 1);
//
//				url = url + "?" + queryString;
//			}
//
//			URLConnection urlConnection = new URL(url).openConnection();
//			HttpURLConnection httpUrlConnection = (HttpURLConnection) urlConnection;
//			// 设置是否向httpUrlConnection输出，post请求，参数要放在http正文内，因此需要设为true,
//			// 默认情况下是false;
//			httpUrlConnection.setDoOutput(false);
//			// 设置是否从httpUrlConnection读入，默认情况下是true;
//			httpUrlConnection.setDoInput(true);
//			// 忽略缓存
//			httpUrlConnection.setUseCaches(false);
//			// 设定请求的方法为"POST"，默认是GET
//			httpUrlConnection.setRequestMethod("GET");
//			httpUrlConnection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
//			httpUrlConnection.setRequestProperty("Charset", "utf-8");
//
//			httpUrlConnection.connect();
//
//			// 获得响应状态
//			int responseCode = httpUrlConnection.getResponseCode();
//
//			if (HttpURLConnection.HTTP_OK == responseCode) {
//
//				baos = new ByteArrayOutputStream();
//
//				byte[] buffer = new byte[1024];
//				int len = 0;
//				in = httpUrlConnection.getInputStream();
//				while ((len = in.read(buffer)) != -1) {
//					baos.write(buffer, 0, len);
//					baos.flush();
//				}
//
//				result.put("success", true);
//				result.put("data", baos.toString("UTF-8"));
//				result.put("code", 200);
//				result.put("msg", "请求成功");
//			} else {
//				result.put("success", false);
//				result.put("code", responseCode);
//				result.put("msg", "请求异常");
//			}
//		} catch (Exception e) {
//			result.put("success", false);
//			result.put("code", 500);
//			result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//		} finally {
//			if (baos != null) {
//				try {
//					baos.close();
//				} catch (IOException e) {
//					result.put("success", false);
//					result.put("code", 500);
//					result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//				}
//			}
//			if (in != null) {
//				try {
//					in.close();
//				} catch (IOException e) {
//					result.put("success", false);
//					result.put("code", 500);
//					result.put("msg", "请求异常，异常信息：" + e.getClass() + "->" + e.getMessage());
//				}
//			}
//		}
//
//		return result;
//	}
//

}
