package busicode;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.net.URLEncoder;
import java.net.UnknownHostException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Random;
import java.util.UUID;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/***
 * 通用工具类
 * 
 * @author Administrator
 *
 */
public class PublicUtil {

	/*********** 【字符串操作】 **********************************/

	/**
	 * 判断字符串是否为空
	 * 
	 * @param pString 要判断的字符串
	 * @return
	 */
	public static Boolean isNullOrWhiteSpace(String pString) {

		if (pString != null) {
			if (pString.trim().equals("") == false) {
				return false; // 不为空
			}
		}

		return true; // 为空
	}

	/**
	 * 过滤特殊字符，防止SQL注入攻击
	 * 
	 * @param pStrInput 输入字符串
	 * @return
	 */
	public static String strConvert(String pStrInput) {
		if ((pStrInput != null) && (pStrInput != "")) {
			// 定义需要过滤的字符。
			String[][] immit = { { "'", "’" }, { "%20", " " }, { "%24", " " }, { "%27", " " }, { "%3a", " " },
					{ "%3b", " " }, { "%3c", " " }, { ";", "；" }, { "+", "＋" }, { "&", "＆" }, { "(", "（" },
					{ ")", "）" }, { "%", "％" }, { "--", "－－" }, { "*", "※" }, { "\\", "、" }, { "|", "｜" },
					{ "@", "＠" }, { "[", "【" }, { "]", "】" }, { "#", "＃" } };
			// 遍历字符串，过滤掉需要过滤的字符
			for (int i = 0; i < (immit.length); i++) {
				// pStrInput = pStrInput.replace(immit[i, 0], immit[i, 1]);
				pStrInput = pStrInput.replace(immit[i][0], immit[i][1]);

				// System.out.println(immit[i][0] + "=" + immit[i][1]);
			}
		}
		return pStrInput;// 返回替换后的字符串
	}

	/**
	 * 删除字符串最前面和最后面指定的字符
	 * 
	 * @param pStringChar 字符串值
	 * @param pRemoveChar 要删除的字符
	 * @param pCharLength 被去掉的有几个字符
	 * @return
	 */
	public static String RemoveFrontAndBackChar(String pStringChar, String pRemoveChar, int pCharLength) {
		if (pCharLength == 0) {
			pCharLength = 1;
		}

		pStringChar = pStringChar.toString().trim();
		pRemoveChar = pRemoveChar.toString().trim();

		if (pStringChar == "") {
			return pStringChar;
		}
		if (pStringChar.length() < pCharLength) {
			return pStringChar;
		}

		// 除去最前面的“,”和最后的“,”
		if (pStringChar.indexOf("" + pRemoveChar + "") == 0) {
			pStringChar = pStringChar.substring(pCharLength);
		}
		if (pStringChar.lastIndexOf("" + pRemoveChar + "") == pStringChar.length() - pCharLength) {
			pStringChar = pStringChar.substring(0, pStringChar.length() - pCharLength);
		}

		// 返回替换后的字符串
		return pStringChar;
	}

	/**
	 * 用指定的字符 拼接一个字符串数组
	 * 
	 * @param pArrayString 字符串数组
	 * @param pJoinChar    拼接的字符 [ " |" ]
	 * @return
	 */
	public static String joinArrayString(String[] pArrayString, String pJoinChar) {
		String _backMsg = "";
		for (int i = 0; i < pArrayString.length; i++) {
			_backMsg += pArrayString[i] + pJoinChar;
		}
		// 删除前后的连接字符串
		_backMsg = RemoveFrontAndBackChar(_backMsg, pJoinChar, 1);

		return _backMsg;
	}

	/**
	 * 如果一个字符串超出了指定的长度，就按指定长度进行分段成数组
	 * 
	 * @param pSectionString 要分段的字符串
	 * @param 指定的每段的字符长度
	 * @return
	 */
	public static String[] splitStringSection(String pSectionString, int pMaxLength) {

		String[] _arrTxtSection = null;

		int _rSAEnTxtLength = pSectionString.length();
		if (_rSAEnTxtLength > pMaxLength) {

			float _float = (float) _rSAEnTxtLength / pMaxLength;

			int _rSAEnTxtArrCount = (int) Math.ceil(_float);
			// 定义数组
			_arrTxtSection = new String[_rSAEnTxtArrCount];
			// 分割加密字符串
			for (int i = 0; i < _rSAEnTxtArrCount; i++) {
				int _lengthLast = pMaxLength * (i + 1);
				// System.out.println("_lengthLast=" + _lengthLast + " |
				// pSectionString.length()=" + pSectionString.length());
				if (_lengthLast >= pSectionString.length()) {
					_arrTxtSection[i] = pSectionString.substring(pMaxLength * i);
					// System.out.println("执行了");
				} else {
					_arrTxtSection[i] = pSectionString.substring(pMaxLength * i, pMaxLength * (i + 1));
				}
			}
		} else {
			_arrTxtSection = new String[1];
			_arrTxtSection[0] = pSectionString;
		}

		return _arrTxtSection;
	}

	/**
	 * 判断字符串末尾，是否是，指定的字符
	 * 
	 * @param pInputStr  输入的字符串
	 * @param pIndexChar 指定的字符
	 * @return
	 */
	public static boolean existLastChar(String pInputStr, String pIndexChar) {

		// 发现字符的位置
		int _lastIndex = pInputStr.lastIndexOf(pIndexChar);
		int _inputStrLength = pInputStr.length();
		System.out.println("_lastIndex=" + _lastIndex + " | _inputStrLength=" + _inputStrLength);
		if (_lastIndex >= _inputStrLength - 1) {
			return true;
		}

		return false;
	}

	/*********** 【日期时间操作】 **********************************/

	/***
	 * 获取当前系统日期时间 yyyy-MM-dd HH:mm:ss
	 * 
	 * @return
	 */
	public static String getCurrentDateTime() {
		SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");// HH:mm:ss
		// 获取当前时间
		Date date = new Date(System.currentTimeMillis());

		return simpleDateFormat.format(date);
		// time1.setText("Date获取当前日期时间"+simpleDateFormat.format(date));
	}
	
	/***
	 * 获取当前系统日期时间 yyyyMMddHHmmss
	 * 
	 * @return
	 */
	public static String getCurrentDateTimeNum() {
		SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmss");// HH:mm:ss
		// 获取当前时间
		Date date = new Date(System.currentTimeMillis());

		return simpleDateFormat.format(date);
		// time1.setText("Date获取当前日期时间"+simpleDateFormat.format(date));
	}
	

	/***
	 * 获取当前系统日期 yyyy-MM-dd
	 * 
	 * @return
	 */
	public static String getCurrentDate() {
		SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");// HH:mm:ss
		// 获取当前时间
		Date date = new Date(System.currentTimeMillis());

		return simpleDateFormat.format(date);
		// time1.setText("Date获取当前日期时间"+simpleDateFormat.format(date));
	}

	/*********** 【Request,Response对象 操作】 **********************************/

	/***
	 * 重定向到Jsp页面,带Request参数,
	 * 
	 * @param req          HttpServletRequest对象
	 * @param resp         HttpServletResponse 对象
	 * @param pPageName    Jsp页面名称,不带拓展名
	 * @param pMapReqParam 带的Request参数，Map键值对
	 */
	public static void requestDispatcherJsp(HttpServletRequest req, HttpServletResponse resp,
			String pPageName, Map<String, String> pMapReqParam) {

		resp.setCharacterEncoding("UTF-8");

		String _reqParams = "";
		// 遍历Map键值对对象的集合，得到每一个键值对对象
		for (Entry<String, String> entry : pMapReqParam.entrySet()) {

			try {
				_reqParams += entry.getKey() + "=" + URLEncoder.encode(entry.getValue().toString(), "UTF-8")
						+ "&";
			} catch (UnsupportedEncodingException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		// 去掉前后的“&”
		_reqParams = RemoveFrontAndBackChar(_reqParams, "&", 1);

		// 重定向
		try {
			req.getRequestDispatcher("" + pPageName + ".jsp?" + _reqParams + "").forward(req, resp);
		} catch (ServletException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/***
	 * 获取当前Web网站项目的根目录
	 * 
	 * @return
	 */
	public static String getWebRootAbsolutePath() {

		// 类文件保存的目录 返回：
		// file:/C:/Java/apache-tomcat-9.0.13/webapps/JavaServletDemo/WEB-INF/classes/
		String _classPath = Thread.currentThread().getContextClassLoader().getResource("").toString();
		// 截取中间的根目录
		String _webRootPath = _classPath.replace("file:/", "").replace("WEB-INF/classes/", "");

		return _webRootPath;
	}

	/**
	 * 获取mac地址
	 * 
	 * @return
	 * @throws UnknownHostException
	 * @throws Exception
	 */
	public static String getMACAddress() {
		InetAddress ia = null;
		try {
			ia = InetAddress.getLocalHost();
		} catch (UnknownHostException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		// 获得网络接口对象（即网卡），并得到mac地址，mac地址存在于一个byte数组中。
		byte[] mac = null;
		try {
			mac = NetworkInterface.getByInetAddress(ia).getHardwareAddress();
		} catch (SocketException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// 下面代码是把mac地址拼装成String
		StringBuffer sb = new StringBuffer();

		for (int i = 0; i < mac.length; i++) {
			if (i != 0) {
				sb.append("-");
			}
			// mac[i] & 0xFF 是为了把byte转化为正整数
			String s = Integer.toHexString(mac[i] & 0xFF);
			sb.append(s.length() == 1 ? 0 + s : s);
		}

		// 把字符串所有小写字母改为大写成为正规的mac地址并返回
		return sb.toString().toUpperCase().replaceAll("-", "");
	}

	/**
	 * 得到客户端IP
	 * 
	 * @param request
	 * @return
	 * @throws Exception
	 */
	public static String getIpAddress(HttpServletRequest req) {
		String ip = req.getHeader("X-Forwarded-For");
		if (ip != null) {
			if (!ip.isEmpty() && !"unKnown".equalsIgnoreCase(ip)) {
				int index = ip.indexOf(",");
				if (index != -1) {
					return ip.substring(0, index);
				} else {
					return ip;
				}
			}
		}
		ip = req.getHeader("X-Real-IP");
		if (ip != null) {
			if (!ip.isEmpty() && !"unKnown".equalsIgnoreCase(ip)) {
				return ip;
			}
		}
		return req.getRemoteAddr();
	}

	/**
	 * 生成GUID 如：f2cacf9c-99fb-4080-a1b4-ff3e0bac857b
	 * 
	 * @return
	 */
	public static String createNewGuid() {

		UUID uuid = UUID.randomUUID();
		return uuid.toString();
	}

	/**
	 * 生成指定位数的随机数
	 * 
	 * @param pDigitNum 随机位数
	 * @return
	 */
	public static String createRndNum(int pDigitNum) {
		String val = "";
		Random random = new Random();
		for (int i = 0; i < pDigitNum; i++) {

			val += String.valueOf(random.nextInt(10));
			if (i == 0 && val.equals("0")) {
				val = createRndNumDiff(1, 9);
			}
		}
		return val;
	}

	/**
	 * 生成指定范围的随机数
	 * 
	 * @param pMinNumber 最小值
	 * @param pMaxNumber 最大值
	 * @return
	 */
	public static String createRndNumDiff(int pMinNumber, int pMaxNumber) {
		int max = pMaxNumber;
		int min = pMinNumber;

		Random random = new Random();
		int s = random.nextInt(max) % (max - min + 1) + min;

		return String.valueOf(s);

	}

	/**
	 * 得到1970到现在的总毫秒数
	 * @return
	 */
	public static String getTotalMilliSeconds() {
	
		return String.valueOf(System.currentTimeMillis());
	}

}
